@@ -83,7 +83,7 @@
 {"Exec",13,77,0,*((ulonglong *) at_Exec)},
 {"FLOOR",13,-124,0,*((ulonglong *) at_FLOOR)},
 {"FNROOT",13,-124,0,*((ulonglong *) at_FNROOT)| 1},
-{"FP",13,-124,0,*((ulonglong *) at_FP)},
+{"FP",13,-124,0,*((ulonglong *) at_FRAC)},
 {"Factor",13,9,0,*((ulonglong *) at_Factor)},
 {"Fahrenheit2Celsius",13,9,0,*((ulonglong *) at_Fahrenheit2Celsius)},
 {"Fill",13,77,0,*((ulonglong *) at_Fill)| 1},
@@ -104,7 +104,7 @@
 {"INPUT",13,-124,0,*((ulonglong *) at_INPUT)| 1},
 {"INTERSECT",13,-124,0,*((ulonglong *) at_INTERSECT)},
 {"INVERSE",13,-124,0,*((ulonglong *) at_INVERSE)},
-{"IP",13,-124,0,*((ulonglong *) at_IP)},
+{"IP",13,-124,0,*((ulonglong *) at_INT)},
 {"ISOLATE",13,-124,0,*((ulonglong *) at_ISOLATE)| 1},
 {"ITERATE",13,-124,0,*((ulonglong *) at_ITERATE)| 1},
 {"Input",13,77,0,*((ulonglong *) at_Input)| 1},
@@ -114,7 +114,7 @@
 {"JordanBlock",13,9,0,*((ulonglong *) at_JordanBlock)},
 {"Kronecker",13,9,0,*((ulonglong *) at_Kronecker)},
 {"LINE",13,-124,0,*((ulonglong *) at_LINE)},
-{"LINEAR?",13,-124,0,*((ulonglong *) at_LINEAR?)| 1},
+{"LINEAR?",13,-124,0,*((ulonglong *) at_IS_LINEAR)| 1},
 {"LN",13,-124,0,*((ulonglong *) at_LN)},
 {"LNP1",13,-124,0,*((ulonglong *) at_LNP1)},
 {"LOG",13,-124,0,*((ulonglong *) at_LOG)},
@@ -744,7 +744,7 @@
 {"ifactor",13,9,0,*((ulonglong *) at_ifactor)},
 {"ifactors",13,9,0,*((ulonglong *) at_ifactors)},
 {"ifft",13,9,0,*((ulonglong *) at_ifft)},
-{"igamma",13,9,0,*((ulonglong *) at_igamma)},
+{"igamma",13,9,0,*((ulonglong *) at_lower_incomplete_gamma)},
 {"igamma_exp",13,9,0,*((ulonglong *) at_igamma_exp)},
 {"igcd",13,9,0,*((ulonglong *) at_igcd)},
 {"igcdex",13,9,0,*((ulonglong *) at_igcdex)},
@@ -805,7 +805,7 @@
 {"is_harmonic_circle_bundle",13,9,0,*((ulonglong *) at_is_harmonic_circle_bundle)},
 {"is_harmonic_line_bundle",13,9,0,*((ulonglong *) at_is_harmonic_line_bundle)},
 {"is_included",13,9,0,*((ulonglong *) at_is_included)},
-{"is_inside",13,9,0,*((ulonglong *) at_is_inside)},
+{"is_inside",13,9,0,*((ulonglong *) at_est_dans)},
 {"is_isosceles",13,9,0,*((ulonglong *) at_is_isosceles)},
 {"is_orthogonal",13,9,0,*((ulonglong *) at_is_orthogonal)},
 {"is_parallel",13,9,0,*((ulonglong *) at_is_parallel)},
@@ -1188,7 +1188,7 @@
 {"reduced_quadric",13,9,0,*((ulonglong *) at_reduced_quadric)},
 {"ref",13,9,0,*((ulonglong *) at_ref)},
 {"reflection",13,9,0,*((ulonglong *) at_reflection)},
-{"regroup",13,9,0,*((ulonglong *) at_regroup)},
+{"regroup",13,9,0,*((ulonglong *) at_regrouper)},
 {"rem",13,9,0,*((ulonglong *) at_rem)},
 {"remain",13,9,0,*((ulonglong *) at_remain)},
 {"remove",13,9,0,*((ulonglong *) at_remove)},
@@ -1404,7 +1404,7 @@
 {"turtle_stack",13,126,0,*((ulonglong *) at_turtle_stack)},
 {"type",13,9,0,*((ulonglong *) at_type)},
 {"ufactor",13,9,0,*((ulonglong *) at_ufactor)},
-{"ugamma",13,9,0,*((ulonglong *) at_ugamma)},
+{"ugamma",13,9,0,*((ulonglong *) at_upper_incomplete_gamma)},
 {"unapply",13,9,0,*((ulonglong *) at_unapply)| 1},
 {"unarchive",13,9,0,*((ulonglong *) at_unarchive)},
 {"unarchive_ti",13,9,0,*((ulonglong *) at_unarchive_ti)},
@@ -1458,5 +1458,5 @@
 {"Σ",13,-124,0,*((ulonglong *) at_HPSUM)| 1},
 {"ΣLIST",13,-124,0,*((ulonglong *) at_SIGMALIST)},
 {"∂",13,-124,0,*((ulonglong *) at_HPDIFF)| 1},
-{"∡",13,22,0,*((ulonglong *) at_∡)},
+{"∡",13,22,0,*((ulonglong *) at_polar_complex)},
 {"∫",13,-124,0,*((ulonglong *) at_HPINT)| 1}
